document.addEventListener('DOMContentLoaded', () => {
  const playButton = document.getElementById('playButton');
  const gameContainer = document.getElementById('game-container');
  const canvas = document.getElementById('gameCanvas');
  const ctx = canvas.getContext('2d');
  
  let gameStarted = false;
  let player = {
    x: 100,
    y: 100,
    width: 30,
    height: 30,
    speed: 5,
    health: 100
  };

  playButton.addEventListener('click', startGame);

  function startGame() {
    if (gameStarted) return;
    gameStarted = true;
    document.getElementById('hero').style.display = 'none';
    gameContainer.style.display = 'block';
    canvas.width = window.innerWidth;
    canvas.height = window.innerHeight;
    gameLoop();
    setupControls();
  }

  function gameLoop() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    drawPlayer();
    if (gameStarted) {
      requestAnimationFrame(gameLoop);
    }
  }

  function drawPlayer() {
    ctx.fillStyle = '#2196f3';
    ctx.fillRect(player.x, player.y, player.width, player.height);
  }

  function setupControls() {
    const keys = {};
    
    window.addEventListener('keydown', (e) => {
      keys[e.key] = true;
      updatePlayerPosition(keys);
    });

    window.addEventListener('keyup', (e) => {
      keys[e.key] = false;
    });
  }

  function updatePlayerPosition(keys) {
    if (keys['w'] || keys['ArrowUp']) {
      player.y = Math.max(0, player.y - player.speed);
    }
    if (keys['s'] || keys['ArrowDown']) {
      player.y = Math.min(canvas.height - player.height, player.y + player.speed);
    }
    if (keys['a'] || keys['ArrowLeft']) {
      player.x = Math.max(0, player.x - player.speed);
    }
    if (keys['d'] || keys['ArrowRight']) {
      player.x = Math.min(canvas.width - player.width, player.x + player.speed);
    }
  }

  window.addEventListener('resize', () => {
    if (gameStarted) {
      canvas.width = window.innerWidth;
      canvas.height = window.innerHeight;
    }
  });
});
